@@ -1,14 +1,4 @@
-library (testthat)
-library (iotables)
-context ("Creating an IO Table")
-#iotable_get ( source = "naio_10_cp1620", geo = "CZ", 
-#              stk_flow = "TOTAL", year = 2010, 
-#              unit = "MIO_NAC", data_directory = 'data-raw')
-
-#test <- iotable_get ( source = "naio_10_pyp1620", geo = "CZ", 
-#              stk_flow = "TOTAL", year = 2010, 
-#              unit = "MIO_NAC", data_directory = 'data-raw')
-
+context ("iotable_get()")
 
 test_that("Necessary input parameters are checked", {
   expect_error(iotable_get(source = 'naio_10_cp1700', 
@@ -20,13 +10,13 @@ test_that("Necessary input parameters are checked", {
 })
 
 
-test_that("correct data is returned", {
+test_that("Correct data is returned by iotable_get()", {
   expect_equal(iotable_get(source = 'germany_1990', 
                            geo = 'DE', year = 1990, 
                            unit = "MIO_EUR", labelling = "iotables")[1,2], 1131)
   expect_equal(as.character(iotable_get(source = 'germany_1990', 
-                           geo = 'DE', year = 1990, 
-                           unit = "MIO_EUR", labelling = 'short')[4,1]), "CPA_G-I")
+                                        geo = 'DE', year = 1990, 
+                                        unit = "MIO_EUR", labelling = 'short')[4,1]), "CPA_G-I")
   expect_equal(as.numeric(iotable_get ( source = "croatia_2010_1800", geo = "HR",
                                         year = 2010, unit = "T_NAC")[1,3]), 
                expected = 164159,  tolerance = 0.6)
@@ -41,7 +31,7 @@ test_that("correct data is returned", {
                                           year = 2010, unit = "T_NAC", 
                                           labelling = "iotables")[[1]][2]), 
                expected = "forestry")
-  })
+})
 
 #Slovakia A01, A01 shoud be 497.37
 
@@ -51,12 +41,12 @@ test_that("correct data is returned", {
 # A01, A01 should yield 10,161
 
 germany_table <- iotable_get(source = 'germany_1990', 
-            geo = 'DE', year = 1990, 
-            unit = "MIO_EUR", labelling = "iotables")
+                             geo = 'DE', year = 1990, 
+                             unit = "MIO_EUR", labelling = "iotables")
 
 hh <- germany_table$final_consumption_households[which( germany_table$iotables_row == "output")]
 
-test_that("correct data is returned for private consumption", {
+test_that("Correct data is returned for private consumption by iotable_get()", {
   expect_equal(hh, 1001060)
 })
 
